@@ -48,7 +48,7 @@ setMethod( "plot", signature( x = "mi.method", y ="ANY"),
     vrb.imp <- imputed( x, y )
     mi.hist(x, vrb.obs, xlab=main, main = main, gray.scale = gray.scale )
     residual.plot( fit, res, sigma, main = main, gray.scale = gray.scale )
-    binnedplot ( fit[ !is.na( y )], res[ !is.na( y )], 
+    binnedplot ( fit[ !is.na( y )], res[ !is.na( y )], col.pts = ifelse(gray.scale, "black", "blue"), 
               nclass = sqrt( length( fit[  !is.na( y )] ) ), main = main )
     mi.scatterplot( vrb.obs, vrb.imp, fit, xlab = "predicted", ylab = main, 
                       main = main, gray.scale = gray.scale )
@@ -112,7 +112,8 @@ function ( x, y, main=deparse( substitute( y ) ), gray.scale = FALSE, ...) {
    vrb.obs <- y
    vrb.imp <- imputed( x, y )
    mi.hist ( x, Yobs=vrb.obs, xlab = main, main = main, gray.scale = gray.scale )
-   binnedplot ( fit[ !is.na( y )], res[ !is.na( y )], nclass = sqrt( length( fit[  !is.na( y )] ) ), main = main )
+   binnedplot ( fit[ !is.na( y )], res[ !is.na( y )], col.pts = ifelse(gray.scale, "black", "blue"), 
+    nclass = sqrt( length( fit[  !is.na( y )] ) ), main = main )
    mtext( "Binned Residual", 3, cex = 0.7, adj = NA )
    mi.scatterplot( Yobs=vrb.obs, vrb.imp, fit, xlab = "Predicted", ylab = main, main = main, gray.scale = gray.scale )
    plot( 0, 0, type = "n", xaxt = "n", yaxt = "n", xlab = "", ylab = "", frame.plot = FALSE )
